@@ -620,7 +620,7 @@ class AgentManagerCommand(AgentCommand):
 
             # Save JSON configuration
             json_file = template_dir / f"{agent_id}.json"
-            with open(json_file, "w") as f:
+            with json_file.open("w") as f:
                 json.dump(config, f, indent=2)
 
             # Save instructions
@@ -712,7 +712,7 @@ class AgentManagerCommand(AgentCommand):
         """Load agent configuration."""
         try:
             return self.builder_service._load_template(agent_id)
-        except:
+        except Exception:
             return None
 
     def _check_conflicts(self, agent_id: str) -> Optional[str]:
