@@ -379,7 +379,7 @@ class AnalyzeCommand(BaseCommand):
             filepath = diagram_dir / filename
 
             try:
-                with open(filepath, "w") as f:
+                with filepath.open("w") as f:
                     # Write mermaid header comment
                     f.write("// Generated by Claude MPM Code Analyzer\n")
                     f.write(f"// Timestamp: {timestamp}\n")
@@ -478,7 +478,7 @@ class AnalyzeCommand(BaseCommand):
         """
         try:
             filepath.parent.mkdir(parents=True, exist_ok=True)
-            with open(filepath, "w") as f:
+            with filepath.open("w") as f:
                 f.write(content)
             self.logger.info(f"Saved output to {filepath}")
         except Exception as e:
