@@ -436,7 +436,7 @@ The final CLAUDE.md should be a comprehensive, well-organized guide that any AI
                 console.print(f"  • {pattern}")
 
         if analysis.get("custom_sections"):
-            console.print("\n[blue]ℹ️  Custom sections found:[/blue]")
+            console.print("\n[blue][INFO]️  Custom sections found:[/blue]")
             for section in analysis["custom_sections"][:5]:
                 console.print(f"  • {section}")
 
@@ -912,10 +912,9 @@ preserving valuable project-specific information while refreshing standard secti
                     )
             finally:
                 # Clean up temporary file
-                import os
 
                 with contextlib.suppress(Exception):
-                    os.unlink(prompt_file)
+                    Path(prompt_file).unlink()
 
             # Display output if verbose
             if verbose and result.stdout:
@@ -965,7 +964,9 @@ preserving valuable project-specific information while refreshing standard secti
             if "libmamba" in error_msg:
                 lines = error_msg.split("\n")
                 error_lines = [
-                    l for l in lines if not l.startswith("warning") and l.strip()
+                    line
+                    for line in lines
+                    if not line.startswith("warning") and line.strip()
                 ]
                 error_msg = "\n".join(error_lines) if error_lines else error_msg
 
