@@ -26,12 +26,11 @@ import traceback
 from abc import ABC, abstractmethod
 from contextlib import asynccontextmanager
 from dataclasses import dataclass, field
-from datetime import datetime, timedelta
+from datetime import datetime, timedelta, timezone
 from pathlib import Path
-from typing import Any, Callable, Dict, List, Optional, Type, Union
+from typing import Any, Dict, List, Optional
 
 from .config import Config
-from .logger import setup_logging
 from .mixins import LoggerMixin
 
 
@@ -145,7 +144,7 @@ class BaseService(LoggerMixin, ABC):
         self._health = ServiceHealth(
             status="unknown",
             message="Service not started",
-            timestamp=datetime.now().isoformat(),
+            timestamp=datetime.now(timezone.utc).isoformat(),
         )
         self._metrics = ServiceMetrics()
         self._last_health_check: Optional[float] = None
@@ -158,13 +157,11 @@ class BaseService(LoggerMixin, ABC):
             self._init_enhanced_features()
 
         # Check for quiet mode
-        default_log_level = "INFO"
         if os.getenv("CLAUDE_PM_QUIET_MODE") == "true":
-            default_log_level = "WARNING"
             self.logger.setLevel(logging.WARNING)
 
         # Only log if not in quiet mode
-        if not os.environ.get("CLAUDE_PM_QUIET_MODE", "").lower() == "true":
+        if os.environ.get("CLAUDE_PM_QUIET_MODE", "").lower() != "true":
             self.logger.debug(f"Initialized {self.name} service")
 
     def _init_enhanced_features(self):
@@ -202,7 +199,7 @@ class BaseService(LoggerMixin, ABC):
     def uptime(self) -> Optional[float]:
         """Get service uptime in seconds."""
         if self._start_time and self._running:
-            return (datetime.now() - self._start_time).total_seconds()
+            return (datetime.now(timezone.utc) - self._start_time).total_seconds()
         return None
 
     @property
@@ -239,8 +236,8 @@ class BaseService(LoggerMixin, ABC):
             self.logger.error(f"Failed to start service {self.name}: {e}")
             self._health = ServiceHealth(
                 status="unhealthy",
-                message=f"Startup failed: {str(e)}",
-                timestamp=datetime.now().isoformat(),
+                message=f"Startup failed: {e!s}",
+                timestamp=datetime.now(timezone.utc).isoformat(),
                 checks={"startup": False},
             )
 
@@ -271,13 +268,13 @@ class BaseService(LoggerMixin, ABC):
 
         # Mark as running
         self._running = True
-        self._start_time = datetime.now()
+        self._start_time = datetime.now(timezone.utc)
 
         # Update health status
         self._health = ServiceHealth(
             status="healthy",
             message="Service started successfully",
-            timestamp=datetime.now().isoformat(),
+            timestamp=datetime.now(timezone.utc).isoformat(),
             checks={"startup": True},
             metrics=self._get_health_metrics() if self._enable_enhanced else {},
         )
@@ -341,7 +338,7 @@ class BaseService(LoggerMixin, ABC):
         self._health = ServiceHealth(
             status="unknown",
             message="Service stopped",
-            timestamp=datetime.now().isoformat(),
+            timestamp=datetime.now(timezone.utc).isoformat(),
             checks={"running": False},
         )
 
@@ -391,7 +388,7 @@ class BaseService(LoggerMixin, ABC):
             self._health = ServiceHealth(
                 status=status,
                 message=message,
-                timestamp=datetime.now().isoformat(),
+                timestamp=datetime.now(timezone.utc).isoformat(),
                 checks=checks,
                 metrics={
                     "uptime": self.uptime,
@@ -406,8 +403,8 @@ class BaseService(LoggerMixin, ABC):
             self.logger.error(f"Health check failed for {self.name}: {e}")
             self._health = ServiceHealth(
                 status="unhealthy",
-                message=f"Health check error: {str(e)}",
-                timestamp=datetime.now().isoformat(),
+                message=f"Health check error: {e!s}",
+                timestamp=datetime.now(timezone.utc).isoformat(),
                 checks={"health_check_error": True},
             )
             return self._health
@@ -431,7 +428,16 @@ class BaseService(LoggerMixin, ABC):
             self.logger.info(
                 f"Received signal {signum}, initiating graceful shutdown..."
             )
-            asyncio.create_task(self.stop())
+            # Get the event loop and create a tracked shutdown task
+            try:
+                loop = asyncio.get_event_loop()
+                task = loop.create_task(self.stop())
+                # Store reference to prevent GC during shutdown
+                if not hasattr(self, "_shutdown_task"):
+                    self._shutdown_task = task
+            except RuntimeError:
+                # No event loop, call stop synchronously
+                self.logger.warning("No event loop available for graceful shutdown")
 
         signal.signal(signal.SIGINT, signal_handler)
         signal.signal(signal.SIGTERM, signal_handler)
@@ -589,7 +595,7 @@ class BaseService(LoggerMixin, ABC):
                     return ServiceHealth(
                         status="degraded",
                         message="Service circuit breaker is open",
-                        timestamp=datetime.now().isoformat(),
+                        timestamp=datetime.now(timezone.utc).isoformat(),
                         checks={"circuit_breaker": False},
                         metrics=self._get_health_metrics(),
                     )
@@ -624,10 +630,9 @@ class BaseService(LoggerMixin, ABC):
         if (
             self._circuit_breaker.failure_count
             >= self._circuit_breaker.failure_threshold
-        ):
-            if self._circuit_breaker.state != "open":
-                self._circuit_breaker.state = "open"
-                self.logger.warning(f"Circuit breaker opened for service {self.name}")
+        ) and self._circuit_breaker.state != "open":
+            self._circuit_breaker.state = "open"
+            self.logger.warning(f"Circuit breaker opened for service {self.name}")
 
     def _record_circuit_success(self) -> None:
         """Record circuit breaker success."""
@@ -706,7 +711,6 @@ class BaseService(LoggerMixin, ABC):
     async def _initialize_dependencies(self) -> None:
         """Initialize service dependencies (enhanced feature)."""
         # Override in subclasses for specific dependency setup
-        pass
 
     async def _register_with_health_monitor(self) -> None:
         """Register service with health monitor (enhanced feature)."""
@@ -729,12 +733,10 @@ class BaseService(LoggerMixin, ABC):
     @abstractmethod
     async def _initialize(self) -> None:
         """Initialize the service. Must be implemented by subclasses."""
-        pass
 
     @abstractmethod
     async def _cleanup(self) -> None:
         """Cleanup service resources. Must be implemented by subclasses."""
-        pass
 
     async def _health_check(self) -> Dict[str, bool]:
         """
@@ -816,7 +818,6 @@ class BaseService(LoggerMixin, ABC):
         - Store aggregated data, not raw events
         - Consider metric cardinality
         """
-        pass
 
     # Utility methods
 
