@@ -80,8 +80,8 @@ def safe_path_join(*parts: Union[str, Path]) -> Path:
     # Ensure the resolved path is under the base path
     try:
         resolved.relative_to(base)
-    except ValueError:
-        raise ValueError(f"Path traversal detected: {path}")
+    except ValueError as e:
+        raise ValueError(f"Path traversal detected: {path}") from e
 
     return resolved
 
@@ -142,7 +142,7 @@ def safe_read(
     """Safely read a file with error handling.
 
     Replaces the common pattern:
-        with open(file, 'r') as f:
+        with file.open('r') as f:
             content = f.read()
 
     Args:
@@ -173,10 +173,10 @@ def safe_read(
 
     try:
         if "b" in mode:
-            with open(filepath, mode) as f:
+            with Path(filepath).open(mode) as f:
                 return f.read()
         else:
-            with open(filepath, mode, encoding=encoding) as f:
+            with Path(filepath).open(mode, encoding=encoding) as f:
                 return f.read()
     except (OSError, UnicodeDecodeError) as e:
         logger.error(f"Error reading file {filepath}: {e}")
@@ -206,7 +206,9 @@ def safe_read_lines(
         return []
 
     try:
-        with open(filepath, encoding=encoding) as f:
+        with Path(filepath).open(
+            encoding=encoding,
+        ) as f:
             lines = []
             for i, line in enumerate(f):
                 if max_lines is not None and i >= max_lines:
@@ -320,10 +322,10 @@ def safe_write(
 
     try:
         if "b" in mode:
-            with open(filepath, mode) as f:
+            with Path(filepath).open(mode) as f:
                 f.write(content)
         else:
-            with open(filepath, mode, encoding=encoding) as f:
+            with Path(filepath).open(mode, encoding=encoding) as f:
                 f.write(content)
         return True
     except OSError as e:
@@ -368,14 +370,14 @@ def atomic_write(
                 f.write(content)
 
         # Atomic rename
-        os.replace(temp_path, filepath)
+        Path(temp_path).replace(filepath)
         return True
 
     except OSError as e:
         logger.error(f"Error in atomic write to {filepath}: {e}")
         # Clean up temporary file
         with suppress(Exception):
-            os.unlink(temp_path)
+            Path(temp_path).unlink()
         return False
 
 
@@ -634,14 +636,14 @@ def file_lock(filepath: Union[str, Path], timeout: float = 5.0):
 
         while True:
             try:
-                lock_handle = open(lock_file, "w")
+                lock_handle = Path(lock_file).open("w")
                 fcntl.flock(lock_handle, fcntl.LOCK_EX | fcntl.LOCK_NB)
                 break
             except OSError as e:
                 if e.errno != errno.EAGAIN:
                     raise
                 if time.time() - start_time > timeout:
-                    raise TimeoutError(f"Could not acquire lock for {filepath}")
+                    raise TimeoutError(f"Could not acquire lock for {filepath}") from e
                 time.sleep(0.1)
 
         yield lock_handle
@@ -724,7 +726,7 @@ def get_file_hash(
 
     try:
         hasher = hashlib.new(algorithm)
-        with open(filepath, "rb") as f:
+        with filepath.open("rb") as f:
             for chunk in iter(lambda: f.read(8192), b""):
                 hasher.update(chunk)
         return hasher.hexdigest()
