@@ -41,6 +41,14 @@ class EventViewer {
         this.socketClient.onEventUpdate((events, sessions) => {
             // Ensure we always have a valid events array
             this.events = Array.isArray(events) ? events : [];
+            console.log('[EventViewer] Events updated - received:', this.events.length);
+
+            // Update debug metrics
+            const debugReceivedEl = document.getElementById('debug-events-received');
+            if (debugReceivedEl) {
+                debugReceivedEl.textContent = this.events.length;
+            }
+
             this.updateDisplay();
         });
     }
@@ -221,8 +229,29 @@ class EventViewer {
      * Render events in the UI
      */
     renderEvents() {
-        const eventsList = document.getElementById('events-list');
-        if (!eventsList) return;
+        // CRITICAL FIX: Use the container passed to constructor, not hardcoded events-list
+        // This prevents events from being rendered in the wrong tab
+        const eventsList = this.container;
+        if (!eventsList) {
+            console.warn('[EventViewer] Container not found, skipping render');
+            return;
+        }
+        
+        // SAFETY: Basic check to ensure we're rendering to the correct container
+        if (eventsList.id !== 'events-list') {
+            console.error('[EventViewer] CRITICAL: Attempting to render to wrong container:', eventsList.id);
+            return;
+        }
+
+        // Check if events tab exists and render regardless of active state
+        // This allows events to be pre-rendered when tab becomes active
+        const eventsTab = document.getElementById('events-tab');
+        if (!eventsTab) {
+            console.warn('[EventViewer] Events tab not found in DOM');
+            return;
+        }
+
+        console.log('[EventViewer] Rendering events - count:', this.filteredEvents.length);
 
         // Check if user is at bottom BEFORE rendering (for autoscroll decision)
         const wasAtBottom = (eventsList.scrollTop + eventsList.clientHeight >= eventsList.scrollHeight - 10);
@@ -268,6 +297,14 @@ class EventViewer {
         // Update filtered elements reference
         this.filteredEventElements = Array.from(eventsList.querySelectorAll('.event-item'));
 
+        console.log('[EventViewer] Events rendered - filtered:', this.filteredEvents.length, 'elements:', this.filteredEventElements.length);
+
+        // Update debug metrics
+        const debugRenderedEl = document.getElementById('debug-events-rendered');
+        if (debugRenderedEl) {
+            debugRenderedEl.textContent = this.filteredEvents.length;
+        }
+
         // Update Dashboard navigation items if we're in the events tab
         if (window.dashboard && window.dashboard.currentTab === 'events' &&
             window.dashboard.tabNavigation && window.dashboard.tabNavigation.events) {
