@@ -7,7 +7,6 @@ Extracted from AgentDeploymentService as part of the refactoring to improve
 maintainability and testability.
 """
 
-import logging
 import re
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Tuple
@@ -327,17 +326,25 @@ class AgentValidator:
             "path": str(agent_file),
             "description": "No description",
             "version": "unknown",
+            "type": "agent",  # Default type
         }
 
         # Extract from YAML frontmatter
         lines = content.split("\n")
         for line in lines:
-            if line.startswith("name:"):
-                agent_info["name"] = line.split(":", 1)[1].strip().strip("\"'")
-            elif line.startswith("description:"):
-                agent_info["description"] = line.split(":", 1)[1].strip().strip("\"'")
-            elif line.startswith("version:"):
-                agent_info["version"] = line.split(":", 1)[1].strip().strip("\"'")
+            stripped_line = line.strip()
+            if stripped_line.startswith("name:"):
+                agent_info["name"] = stripped_line.split(":", 1)[1].strip().strip("\"'")
+            elif stripped_line.startswith("description:"):
+                agent_info["description"] = (
+                    stripped_line.split(":", 1)[1].strip().strip("\"'")
+                )
+            elif stripped_line.startswith("version:"):
+                agent_info["version"] = (
+                    stripped_line.split(":", 1)[1].strip().strip("\"'")
+                )
+            elif stripped_line.startswith("type:"):
+                agent_info["type"] = stripped_line.split(":", 1)[1].strip().strip("\"'")
 
         return agent_info
 
