@@ -22,8 +22,7 @@ following the naming convention: {agent_id}_memories.md
 """
 
 import logging
-import os
-from typing import Any, Dict, List, Optional, Tuple
+from typing import Any, ClassVar, Dict, List, Optional, Tuple
 
 from claude_mpm.core.config import Config
 from claude_mpm.core.interfaces import MemoryServiceInterface
@@ -54,7 +53,7 @@ class AgentMemoryManager(MemoryServiceInterface):
 
     # Default limits - will be overridden by configuration
     # Updated to support 20k tokens (~80KB) for enhanced memory capacity
-    DEFAULT_MEMORY_LIMITS = {
+    DEFAULT_MEMORY_LIMITS: ClassVar[dict[str, int]] = {
         "max_file_size_kb": 80,  # Increased from 8KB to 80KB (20k tokens)
         "max_items": 100,  # Maximum total memory items
         "max_line_length": 120,
@@ -78,7 +77,7 @@ class AgentMemoryManager(MemoryServiceInterface):
         self.config = config or Config()
         self.project_root = get_path_manager().project_root
         # Use current working directory by default, not project root
-        self.working_directory = working_directory or Path(os.getcwd())
+        self.working_directory = working_directory or Path(Path.cwd())
 
         # Use only project memory directory
         self.project_memories_dir = self.working_directory / ".claude-mpm" / "memories"
@@ -387,31 +386,32 @@ class AgentMemoryManager(MemoryServiceInterface):
                         memory_items = data["Remember"]
 
                     # Process memory items if found and not null
-                    if memory_items is not None and memory_items != "null":
-                        # Skip if explicitly null or empty list
-                        if isinstance(memory_items, list) and len(memory_items) > 0:
-                            # Filter out empty strings and None values
-                            valid_items = []
-                            for item in memory_items:
-                                if item and isinstance(item, str) and item.strip():
-                                    valid_items.append(item.strip())
+                    if (
+                        memory_items is not None
+                        and memory_items != "null"
+                        and isinstance(memory_items, list)
+                        and len(memory_items) > 0
+                    ):
+                        # Filter out empty strings and None values
+                        valid_items = []
+                        for item in memory_items:
+                            if item and isinstance(item, str) and item.strip():
+                                valid_items.append(item.strip())
 
-                            # Only proceed if we have valid items
-                            if valid_items:
+                        # Only proceed if we have valid items
+                        if valid_items:
+                            self.logger.info(
+                                f"Found {len(valid_items)} memory items for {agent_id}: {valid_items[:2]}..."
+                            )
+                            success = self._add_learnings_to_memory(
+                                agent_id, valid_items
+                            )
+                            if success:
                                 self.logger.info(
-                                    f"Found {len(valid_items)} memory items for {agent_id}: {valid_items[:2]}..."
-                                )
-                                success = self._add_learnings_to_memory(
-                                    agent_id, valid_items
-                                )
-                                if success:
-                                    self.logger.info(
-                                        f"Successfully saved {len(valid_items)} memories for {agent_id} to project directory"
-                                    )
-                                    return True
-                                self.logger.error(
-                                    f"Failed to save memories for {agent_id}"
+                                    f"Successfully saved {len(valid_items)} memories for {agent_id} to project directory"
                                 )
+                                return True
+                            self.logger.error(f"Failed to save memories for {agent_id}")
 
                 except json.JSONDecodeError as je:
                     # Not valid JSON, continue to next match
