@@ -166,7 +166,7 @@ class PathResolver(IPathResolver):
         self.logger.debug(f"No project root found from {start_path}")
         return None
 
-    def detect_framework_path(self) -> Optional[Path]:  # noqa: PLR0911
+    def detect_framework_path(self) -> Optional[Path]:
         """
         Auto-detect claude-mpm framework using unified path management.
 
@@ -431,11 +431,14 @@ class PathResolver(IPathResolver):
         ]
 
         for candidate in candidates:
-            if candidate and candidate.exists():
-                # Check for claude-mpm agents directory
-                if (candidate / "src" / "claude_mpm" / "agents").exists():
-                    self.logger.info(f"Found claude-mpm at: {candidate}")
-                    return candidate
+            if (
+                candidate
+                and candidate.exists()
+                and (candidate / "src" / "claude_mpm" / "agents").exists()
+            ):
+                # Found claude-mpm agents directory
+                self.logger.info(f"Found claude-mpm at: {candidate}")
+                return candidate
 
         return None
 
