@@ -369,7 +369,7 @@ class MCPServicesCheck(BaseDiagnosticCheck):
                             stderr_output = stderr_data.decode(
                                 "utf-8", errors="ignore"
                             )[:200]
-                    except:
+                    except (asyncio.TimeoutError, OSError):
                         pass
 
                 if stderr_output:
@@ -391,7 +391,7 @@ class MCPServicesCheck(BaseDiagnosticCheck):
                             stderr_output = stderr_data.decode(
                                 "utf-8", errors="ignore"
                             )[:200]
-                    except:
+                    except (asyncio.TimeoutError, OSError):
                         pass
 
                 if stderr_output:
@@ -444,11 +444,14 @@ class MCPServicesCheck(BaseDiagnosticCheck):
             details["command_path"] = command_path
 
         # If not directly accessible, try pipx run command
-        if not accessible and "pipx_run_command" in config:
-            if self._verify_command_works(config["pipx_run_command"]):
-                accessible = True
-                details["accessible_via_pipx_run"] = True
-                details["pipx_run_available"] = True
+        if (
+            not accessible
+            and "pipx_run_command" in config
+            and self._verify_command_works(config["pipx_run_command"])
+        ):
+            accessible = True
+            details["accessible_via_pipx_run"] = True
+            details["pipx_run_available"] = True
 
         # Check for installation in various locations
         if not pipx_installed and not accessible:
@@ -690,35 +693,34 @@ class MCPServicesCheck(BaseDiagnosticCheck):
                 if any(
                     keyword in output
                     for keyword in ["version", "v1.", "v0.", "1.", "0."]
+                ) and not any(
+                    error in output
+                    for error in [
+                        "error",
+                        "not found",
+                        "no such",
+                        "command not found",
+                    ]
                 ):
-                    # But reject if it's an error message
-                    if not any(
-                        error in output
-                        for error in [
-                            "error",
-                            "not found",
-                            "no such",
-                            "command not found",
-                        ]
-                    ):
-                        return True
+                    return True
 
             # For some tools, non-zero return code is OK if version is shown
             elif "--version" in command or "--help" in command:
                 output = (result.stdout + result.stderr).lower()
                 # Must have version info and no error indicators
-                if "version" in output or "v1." in output or "v0." in output:
-                    if not any(
-                        error in output
-                        for error in [
-                            "error",
-                            "not found",
-                            "no such",
-                            "command not found",
-                            "traceback",
-                        ]
-                    ):
-                        return True
+                if (
+                    "version" in output or "v1." in output or "v0." in output
+                ) and not any(
+                    error in output
+                    for error in [
+                        "error",
+                        "not found",
+                        "no such",
+                        "command not found",
+                        "traceback",
+                    ]
+                ):
+                    return True
 
         except (subprocess.SubprocessError, FileNotFoundError, OSError):
             pass
@@ -778,7 +780,7 @@ class MCPServicesCheck(BaseDiagnosticCheck):
             return None
 
         try:
-            with open(claude_config_path) as f:
+            with claude_config_path.open() as f:
                 config = json.load(f)
 
             mcp_servers = config.get("mcpServers", {})
@@ -869,7 +871,7 @@ class MCPServicesCheck(BaseDiagnosticCheck):
 
             # Create backup
             backup_path = config_path.with_suffix(".json.backup")
-            with open(backup_path, "w") as f:
+            with backup_path.open("w") as f:
                 json.dump(config, f, indent=2)
 
             # Update the configuration - ensure we're setting the exact new_args
@@ -884,11 +886,11 @@ class MCPServicesCheck(BaseDiagnosticCheck):
                 return False
 
             # Write updated configuration
-            with open(config_path, "w") as f:
+            with config_path.open("w") as f:
                 json.dump(config, f, indent=2)
 
             # Verify the file was written correctly
-            with open(config_path) as f:
+            with config_path.open() as f:
                 verify_config = json.load(f)
                 verify_args = (
                     verify_config.get("mcpServers", {})
@@ -902,9 +904,9 @@ class MCPServicesCheck(BaseDiagnosticCheck):
                         f"Expected {new_args}, got {verify_args}"
                     )
                     # Restore backup
-                    with open(backup_path) as bf:
+                    with backup_path.open() as bf:
                         backup_config = json.load(bf)
-                    with open(config_path, "w") as f:
+                    with config_path.open("w") as f:
                         json.dump(backup_config, f, indent=2)
                     return False
 
@@ -936,7 +938,7 @@ class MCPServicesCheck(BaseDiagnosticCheck):
                     fix_description="Initialize Claude configuration",
                 )
 
-            with open(config_file) as f:
+            with config_file.open() as f:
                 config = json.load(f)
 
             # Get the current project configuration
