@@ -15,7 +15,7 @@ DESIGN DECISIONS:
 import re
 from datetime import datetime
 from pathlib import Path
-from typing import Any, Dict, Optional
+from typing import Any, ClassVar, Dict, Optional
 
 from ..models import DiagnosticResult, DiagnosticStatus
 from .base_check import BaseDiagnosticCheck
@@ -25,7 +25,7 @@ class StartupLogCheck(BaseDiagnosticCheck):
     """Analyze startup logs for errors and issues."""
 
     # Common error patterns and their fixes
-    ERROR_PATTERNS = {
+    ERROR_PATTERNS: ClassVar[dict[str, dict[str, Any]]] = {
         r"Agent deployment.*failed": (
             "Agent deployment failure",
             "Check agent configuration in .claude/agents/ and run 'claude-mpm deploy'",
@@ -186,7 +186,9 @@ class StartupLogCheck(BaseDiagnosticCheck):
         }
 
         try:
-            with open(log_file, encoding="utf-8") as f:
+            with Path(log_file).open(
+                encoding="utf-8",
+            ) as f:
                 lines = f.readlines()
 
             # Extract timestamp from filename or first line
