@@ -63,7 +63,7 @@ except ImportError:
 try:
     from claude_mpm.services.mcp_gateway.server.mcp_gateway import MCPGateway
 except ImportError as e:
-    raise ImportError(f"Critical: Cannot import MCPGateway server: {e}")
+    raise ImportError(f"Critical: Cannot import MCPGateway server: {e}") from e
 
 try:
     from claude_mpm.services.mcp_gateway.server.stdio_handler import StdioHandler
@@ -179,10 +179,13 @@ class MCPGatewayOrchestrator:
 
             # Load configuration
             self.configuration = MCPConfiguration()
-            if self.config_path and self.config_path.exists():
-                if not self.configuration.load_config(self.config_path):
-                    self.logger.error("Failed to load configuration")
-                    return False
+            if (
+                self.config_path
+                and self.config_path.exists()
+                and not self.configuration.load_config(self.config_path)
+            ):
+                self.logger.error("Failed to load configuration")
+                return False
 
             # Initialize tool registry with error handling
             try:
