@@ -18,6 +18,7 @@ import os
 import sys
 import time
 from datetime import timezone
+from pathlib import Path
 from typing import Any, Dict
 
 # Import MCP SDK components
@@ -541,12 +542,10 @@ class SimpleMCPServer:
 
                         result = f"Python: {sys.version}"
                     elif info_type == "cwd":
-                        import os
 
-                        result = f"Working Directory: {os.getcwd()}"
+                        result = f"Working Directory: {Path.cwd()}"
                     elif info_type == "all":
                         import datetime
-                        import os
                         import platform
                         import sys
 
@@ -554,7 +553,7 @@ class SimpleMCPServer:
                             f"=== System Status ===\n"
                             f"Platform: {platform.system()} {platform.release()}\n"
                             f"Python: {sys.version.split()[0]}\n"
-                            f"Working Directory: {os.getcwd()}\n"
+                            f"Working Directory: {Path.cwd()}\n"
                             f"Server: {self.name} v{self.version}\n"
                             f"Timestamp: {datetime.datetime.now(timezone.utc).isoformat()}\n"
                             f"Tools Available: status, document_summarizer{', ticket' if self.unified_ticket_tool else ''}"
