@@ -10,7 +10,6 @@ Part of ISS-0037: Document Summarizer Tool - Intelligent Document Processing
 
 import hashlib
 import mimetypes
-import os
 import re
 from collections import OrderedDict
 from datetime import datetime, timezone
@@ -240,7 +239,7 @@ class DocumentSummarizerTool(BaseToolAdapter):
 
     def _get_file_hash(self, file_path: str) -> str:
         """Generate hash for file caching."""
-        stat = os.stat(file_path)
+        stat = Path(file_path).stat()
         hash_input = f"{file_path}:{stat.st_size}:{stat.st_mtime}"
         return hashlib.md5(hash_input.encode()).hexdigest()
 
@@ -306,7 +305,7 @@ class DocumentSummarizerTool(BaseToolAdapter):
                 continue
 
         # If all fail, read as binary and decode with errors='ignore'
-        with open(file_path, "rb") as f:
+        with file_path.open("rb") as f:
             content = f.read()
             return content.decode("utf-8", errors="ignore")
 
