@@ -328,13 +328,11 @@ class MCPServiceVerifier:
             if any(
                 word in output
                 for word in ["version", "usage", "help", service_name.lower()]
+            ) and not any(
+                error in output
+                for error in ["error", "not found", "traceback", "no module"]
             ):
-                # Make sure it's not an error
-                if not any(
-                    error in output
-                    for error in ["error", "not found", "traceback", "no module"]
-                ):
-                    return True
+                return True
 
             # Try pipx run as fallback
             if shutil.which("pipx"):
@@ -429,7 +427,7 @@ class MCPServiceVerifier:
             return {"configured": False, "correct": False}
 
         try:
-            with open(self.claude_config_path) as f:
+            with self.claude_config_path.open() as f:
                 config = json.load(f)
 
             # Check if project is configured
@@ -485,16 +483,19 @@ class MCPServiceVerifier:
                         }
             else:
                 # Direct execution - command should be a valid path
-                if not Path(command).exists() and command != installed_path:
-                    # Allow for relative paths that might resolve differently
-                    if not shutil.which(command):
-                        return {
-                            "configured": True,
-                            "correct": False,
-                            "command": command,
-                            "args": args,
-                            "issue": f"Command path does not exist: {command}",
-                        }
+                if (
+                    not Path(command).exists()
+                    and command != installed_path
+                    and not shutil.which(command)
+                ):
+                    # Command path does not exist and cannot be found
+                    return {
+                        "configured": True,
+                        "correct": False,
+                        "command": command,
+                        "args": args,
+                        "issue": f"Command path does not exist: {command}",
+                    }
 
                 # Check required args
                 for req_arg in required_args:
@@ -615,7 +616,7 @@ class MCPServiceVerifier:
             if diagnostic.fix_command.startswith("chmod "):
                 # Fix permissions
                 path = diagnostic.fix_command.replace("chmod +x ", "")
-                os.chmod(path, 0o755)
+                Path(path).chmod(0o755)
                 return True
 
             if "claude-mpm configure" in diagnostic.fix_command:
