@@ -15,10 +15,11 @@ DESIGN DECISIONS:
 """
 
 import asyncio
+import contextlib
 import os
 import threading
 import time
-from datetime import datetime
+from datetime import datetime, timezone
 from pathlib import Path
 from typing import Dict, Optional
 
@@ -28,7 +29,6 @@ from aiohttp import web
 from ...core.logging_config import get_logger
 from ...dashboard.api.simple_directory import list_directory
 from .event_emitter import get_event_emitter
-from .handlers.browser import BrowserHandler
 from .handlers.code_analysis import CodeAnalysisHandler
 from .handlers.dashboard import DashboardHandler
 from .handlers.file import FileHandler
@@ -69,7 +69,6 @@ class UnifiedMonitorServer:
         self.site = None
 
         # Event handlers
-        self.browser_handler = None
         self.code_analysis_handler = None
         self.dashboard_handler = None
         self.file_handler = None
@@ -272,14 +271,12 @@ class UnifiedMonitorServer:
         """Setup Socket.IO event handlers."""
         try:
             # Create event handlers
-            self.browser_handler = BrowserHandler(self.sio)
             self.code_analysis_handler = CodeAnalysisHandler(self.sio)
             self.dashboard_handler = DashboardHandler(self.sio)
             self.file_handler = FileHandler(self.sio)
             self.hook_handler = HookHandler(self.sio)
 
             # Register handlers
-            self.browser_handler.register()
             self.code_analysis_handler.register()
             self.dashboard_handler.register()
             self.file_handler.register()
@@ -316,7 +313,7 @@ class UnifiedMonitorServer:
             async def dashboard_index(request):
                 template_path = dashboard_dir / "templates" / "index.html"
                 if template_path.exists():
-                    with open(template_path) as f:
+                    with template_path.open() as f:
                         content = f.read()
                     return web.Response(text=content, content_type="text/html")
                 return web.Response(text="Dashboard not found", status=404)
@@ -352,7 +349,7 @@ class UnifiedMonitorServer:
                     data = await request.json()
 
                     # Extract event data
-                    namespace = data.get("namespace", "hook")
+                    data.get("namespace", "hook")
                     event = data.get("event", "claude_event")
                     event_data = data.get("data", {})
 
@@ -371,25 +368,24 @@ class UnifiedMonitorServer:
             async def api_file_handler(request):
                 """Handle file content requests."""
                 import json
-                import os
 
                 try:
                     data = await request.json()
                     file_path = data.get("path", "")
 
                     # Security check: ensure path is absolute and exists
-                    if not file_path or not os.path.isabs(file_path):
+                    if not file_path or not Path(file_path).is_absolute():
                         return web.json_response(
                             {"success": False, "error": "Invalid file path"}, status=400
                         )
 
                     # Check if file exists and is readable
-                    if not os.path.exists(file_path):
+                    if not Path(file_path).exists():
                         return web.json_response(
                             {"success": False, "error": "File not found"}, status=404
                         )
 
-                    if not os.path.isfile(file_path):
+                    if not Path(file_path).is_file():
                         return web.json_response(
                             {"success": False, "error": "Path is not a file"},
                             status=400,
@@ -397,7 +393,7 @@ class UnifiedMonitorServer:
 
                     # Read file content (with size limit for safety)
                     max_size = 10 * 1024 * 1024  # 10MB limit
-                    file_size = os.path.getsize(file_path)
+                    file_size = Path(file_path).stat().st_size
 
                     if file_size > max_size:
                         return web.json_response(
@@ -409,7 +405,9 @@ class UnifiedMonitorServer:
                         )
 
                     try:
-                        with open(file_path, encoding="utf-8") as f:
+                        with Path(file_path).open(
+                            encoding="utf-8",
+                        ) as f:
                             content = f.read()
                             lines = content.count("\n") + 1
                     except UnicodeDecodeError:
@@ -420,7 +418,7 @@ class UnifiedMonitorServer:
                         )
 
                     # Get file extension for type detection
-                    file_ext = os.path.splitext(file_path)[1].lstrip(".")
+                    file_ext = Path(file_path).suffix.lstrip(".")
 
                     return web.json_response(
                         {
@@ -478,13 +476,12 @@ class UnifiedMonitorServer:
             # Configuration endpoint for dashboard initialization
             async def config_handler(request):
                 """Return configuration for dashboard initialization."""
-                import os
                 import subprocess
 
                 config = {
-                    "workingDirectory": os.getcwd(),
+                    "workingDirectory": Path.cwd(),
                     "gitBranch": "Unknown",
-                    "serverTime": datetime.utcnow().isoformat() + "Z",
+                    "serverTime": datetime.now(timezone.utc).isoformat() + "Z",
                     "service": "unified-monitor",
                 }
 
@@ -495,7 +492,7 @@ class UnifiedMonitorServer:
                         capture_output=True,
                         text=True,
                         timeout=2,
-                        cwd=os.getcwd(),
+                        cwd=Path.cwd(),
                         check=False,
                     )
                     if result.returncode == 0 and result.stdout.strip():
@@ -509,221 +506,23 @@ class UnifiedMonitorServer:
             async def working_directory_handler(request):
                 """Return the current working directory."""
                 return web.json_response(
-                    {"working_directory": os.getcwd(), "success": True}
+                    {"working_directory": Path.cwd(), "success": True}
                 )
 
-            # Browser monitor script endpoint
-            async def browser_monitor_script_handler(request):
-                """Serve the browser console monitoring script with dynamic port injection."""
-                try:
-                    # Read the browser monitor script template
-                    script_path = (
-                        dashboard_dir / "static" / "js" / "browser-console-monitor.js"
-                    )
+            # Monitor page routes
+            async def monitor_page_handler(request):
+                """Serve monitor HTML pages."""
+                page_name = request.match_info.get("page", "agents")
+                static_dir = dashboard_dir / "static"
+                file_path = static_dir / f"{page_name}.html"
 
-                    if not script_path.exists():
-                        return web.Response(
-                            text="Browser monitor script not found",
-                            status=404,
-                            content_type="text/javascript",
-                        )
-
-                    # Read script content
-                    with open(script_path, encoding="utf-8") as f:
-                        script_content = f.read()
-
-                    # Replace the port placeholder with actual monitor port
-                    script_content = script_content.replace(
-                        "__MONITOR_PORT__", str(self.port)
-                    )
-
-                    # Set appropriate headers for JavaScript
-                    headers = {
-                        "Content-Type": "application/javascript; charset=utf-8",
-                        "Access-Control-Allow-Origin": "*",
-                        "Access-Control-Allow-Methods": "GET, OPTIONS",
-                        "Access-Control-Allow-Headers": "Content-Type",
-                        "Cache-Control": "no-cache, no-store, must-revalidate",
-                        "Pragma": "no-cache",
-                        "Expires": "0",
-                    }
-
-                    return web.Response(text=script_content, headers=headers)
-
-                except Exception as e:
-                    self.logger.error(f"Error serving browser monitor script: {e}")
-                    return web.Response(
-                        text=f"// Error loading browser monitor script: {e}",
-                        status=500,
-                        content_type="application/javascript",
-                    )
-
-            # Browser log endpoints
-            async def api_browser_logs_handler(request):
-                """Return list of browser log files."""
-                try:
-                    from pathlib import Path
-
-                    # Get browser log directory
-                    log_dir = Path.home() / ".claude-mpm" / "logs" / "client"
-
-                    if not log_dir.exists():
-                        return web.json_response({"files": [], "total": 0})
-
-                    # Get all log files
-                    log_files = []
-                    for file_path in log_dir.glob("*.log"):
-                        stat = file_path.stat()
-                        log_files.append(
-                            {
-                                "name": file_path.name,
-                                "size": stat.st_size,
-                                "modified": stat.st_mtime,
-                                "modified_iso": datetime.fromtimestamp(
-                                    stat.st_mtime
-                                ).isoformat(),
-                            }
-                        )
-
-                    # Sort by modification time (newest first)
-                    log_files.sort(key=lambda x: x["modified"], reverse=True)
-
-                    return web.json_response(
-                        {
-                            "files": log_files,
-                            "total": len(log_files),
-                            "directory": str(log_dir),
-                        }
-                    )
-
-                except Exception as e:
-                    self.logger.error(f"Error listing browser logs: {e}")
-                    return web.json_response(
-                        {"error": str(e), "files": [], "total": 0}, status=500
-                    )
-
-            async def api_browser_log_file_handler(request):
-                """Return contents of specific browser log file."""
-                try:
-                    import json
-                    from pathlib import Path
-
-                    filename = request.match_info.get("filename", "")
-
-                    # Security: ensure filename is safe (no path traversal)
-                    if (
-                        not filename
-                        or "/" in filename
-                        or "\\" in filename
-                        or ".." in filename
-                    ):
-                        return web.json_response(
-                            {"error": "Invalid filename"}, status=400
-                        )
-
-                    # Get log file path
-                    log_dir = Path.home() / ".claude-mpm" / "logs" / "client"
-                    log_file = log_dir / filename
-
-                    # Check if file exists and is within log directory
-                    if not log_file.exists() or not log_file.is_file():
-                        return web.json_response(
-                            {"error": "Log file not found"}, status=404
-                        )
-
-                    # Ensure file is within the log directory (security check)
-                    try:
-                        log_file.resolve().relative_to(log_dir.resolve())
-                    except ValueError:
-                        return web.json_response(
-                            {"error": "Invalid file path"}, status=403
-                        )
-
-                    # Read log entries
-                    entries = []
-                    with open(log_file, encoding="utf-8") as f:
-                        for line in f:
-                            line = line.strip()
-                            if line:
-                                try:
-                                    entry = json.loads(line)
-                                    entries.append(entry)
-                                except json.JSONDecodeError:
-                                    # If not JSON, treat as plain text log
-                                    entries.append(
-                                        {
-                                            "timestamp": "",
-                                            "level": "INFO",
-                                            "message": line,
-                                        }
-                                    )
-
-                    # Limit entries for performance
-                    max_entries = 1000
-                    if len(entries) > max_entries:
-                        entries = entries[-max_entries:]  # Get last N entries
-
-                    return web.json_response(
-                        {
-                            "filename": filename,
-                            "entries": entries,
-                            "total": len(entries),
-                            "truncated": len(entries) == max_entries,
-                        }
-                    )
-
-                except Exception as e:
-                    self.logger.error(f"Error reading browser log file: {e}")
-                    return web.json_response(
-                        {"error": str(e), "entries": []}, status=500
-                    )
-
-            async def api_browser_log_handler(request):
-                """Handle browser log submissions from injected monitoring script."""
-                try:
-                    import json
-                    from pathlib import Path
-
-                    data = await request.json()
-
-                    # Extract log data
-                    browser_id = data.get("browser_id", "unknown")
-                    timestamp = data.get("timestamp", datetime.utcnow().isoformat())
-                    level = data.get("level", "INFO")
-                    message = data.get("message", "")
-                    url = data.get("url", "")
-                    user_agent = data.get("userAgent", "")
-
-                    # Create log entry
-                    log_entry = {
-                        "browser_id": browser_id,
-                        "timestamp": timestamp,
-                        "level": level,
-                        "message": message,
-                        "url": url,
-                        "user_agent": user_agent,
-                    }
-
-                    # Save to file
-                    log_dir = Path.home() / ".claude-mpm" / "logs" / "client"
-                    log_dir.mkdir(parents=True, exist_ok=True)
-
-                    # Use browser ID in filename for easy filtering
-                    log_file = log_dir / f"{browser_id}.log"
-
-                    # Append to log file
-                    with open(log_file, "a", encoding="utf-8") as f:
-                        f.write(json.dumps(log_entry) + "\n")
-
-                    # Also emit to Socket.IO for real-time viewing
-                    if self.sio:
-                        await self.sio.emit("browser_log", log_entry)
-
-                    return web.Response(status=204)  # No content
-
-                except Exception as e:
-                    self.logger.error(f"Error handling browser log: {e}")
-                    return web.Response(text=str(e), status=500)
+                if file_path.exists() and file_path.is_file():
+                    with Path(file_path).open(
+                        encoding="utf-8",
+                    ) as f:
+                        content = f.read()
+                    return web.Response(text=content, content_type="text/html")
+                return web.Response(text="Page not found", status=404)
 
             # Register routes
             self.app.router.add_get("/", dashboard_index)
@@ -732,17 +531,20 @@ class UnifiedMonitorServer:
             self.app.router.add_get("/api/config", config_handler)
             self.app.router.add_get("/api/working-directory", working_directory_handler)
             self.app.router.add_get("/api/directory", list_directory)
-            self.app.router.add_get(
-                "/api/browser-monitor.js", browser_monitor_script_handler
-            )
-            self.app.router.add_get("/api/browser-logs", api_browser_logs_handler)
-            self.app.router.add_get(
-                "/api/browser-logs/{filename}", api_browser_log_file_handler
-            )
-            self.app.router.add_post("/api/browser-log", api_browser_log_handler)
             self.app.router.add_post("/api/events", api_events_handler)
             self.app.router.add_post("/api/file", api_file_handler)
 
+            # Monitor page routes
+            self.app.router.add_get("/monitor", lambda r: monitor_page_handler(r))
+            self.app.router.add_get(
+                "/monitor/agents", lambda r: monitor_page_handler(r)
+            )
+            self.app.router.add_get("/monitor/tools", lambda r: monitor_page_handler(r))
+            self.app.router.add_get("/monitor/files", lambda r: monitor_page_handler(r))
+            self.app.router.add_get(
+                "/monitor/events", lambda r: monitor_page_handler(r)
+            )
+
             # Static files with cache busting headers for development
             static_dir = dashboard_dir / "static"
             if static_dir.exists():
@@ -861,7 +663,7 @@ class UnifiedMonitorServer:
 
                 # Create heartbeat data
                 heartbeat_data = {
-                    "timestamp": datetime.utcnow().isoformat() + "Z",
+                    "timestamp": datetime.now(timezone.utc).isoformat() + "Z",
                     "type": "heartbeat",
                     "server_uptime": uptime_seconds,
                     "server_uptime_formatted": uptime_str,
@@ -891,10 +693,8 @@ class UnifiedMonitorServer:
             # Cancel heartbeat task if running
             if self.heartbeat_task and not self.heartbeat_task.done():
                 self.heartbeat_task.cancel()
-                try:
+                with contextlib.suppress(asyncio.CancelledError):
                     await self.heartbeat_task
-                except asyncio.CancelledError:
-                    pass
                 self.logger.debug("Heartbeat task cancelled")
 
             # Close the Socket.IO server first to stop accepting new connections
@@ -961,7 +761,6 @@ class UnifiedMonitorServer:
             "host": self.host,
             "port": self.port,
             "handlers": {
-                "browser": self.browser_handler is not None,
                 "code_analysis": self.code_analysis_handler is not None,
                 "dashboard": self.dashboard_handler is not None,
                 "file": self.file_handler is not None,
