@@ -21,7 +21,7 @@ import time
 from dataclasses import dataclass
 from datetime import timezone
 from pathlib import Path
-from typing import Any, Dict, List, Optional
+from typing import Any, ClassVar, Dict, List, Optional
 
 try:
     import pathspec
@@ -31,14 +31,13 @@ except ImportError:
     PATHSPEC_AVAILABLE = False
     pathspec = None
 
-try:
+import importlib.util
+
+if importlib.util.find_spec("tree_sitter"):
     import tree_sitter
-    import tree_sitter_javascript
-    import tree_sitter_python
-    import tree_sitter_typescript
 
     TREE_SITTER_AVAILABLE = True
-except ImportError:
+else:
     TREE_SITTER_AVAILABLE = False
     tree_sitter = None
 
@@ -54,7 +53,7 @@ class GitignoreManager:
     """
 
     # Default patterns that should always be ignored
-    DEFAULT_PATTERNS = [
+    DEFAULT_PATTERNS: ClassVar[list] = [
         ".git/",
         "__pycache__/",
         "*.pyc",
@@ -88,13 +87,13 @@ class GitignoreManager:
     ]
 
     # Additional patterns to hide dotfiles (when enabled)
-    DOTFILE_PATTERNS = [
+    DOTFILE_PATTERNS: ClassVar[list] = [
         ".*",  # All dotfiles
         ".*/",  # All dot directories
     ]
 
     # Important files/directories to always show
-    DOTFILE_EXCEPTIONS = {
+    DOTFILE_EXCEPTIONS: ClassVar[set] = {
         # Removed .gitignore from exceptions - it should be hidden by default
         ".env.example",
         ".env.sample",
@@ -260,7 +259,9 @@ class GitignoreManager:
 
         patterns = []
         try:
-            with open(gitignore_path, encoding="utf-8") as f:
+            with Path(gitignore_path).open(
+                encoding="utf-8",
+            ) as f:
                 for line in f:
                     line = line.strip()
                     # Skip empty lines and comments
@@ -383,7 +384,9 @@ class PythonAnalyzer:
         nodes = []
 
         try:
-            with open(file_path, encoding="utf-8") as f:
+            with Path(file_path).open(
+                encoding="utf-8",
+            ) as f:
                 source = f.read()
 
             tree = ast.parse(source, filename=str(file_path))
@@ -635,7 +638,7 @@ class MultiLanguageAnalyzer:
     allowing us to support JavaScript, TypeScript, and other languages.
     """
 
-    LANGUAGE_PARSERS = {
+    LANGUAGE_PARSERS: ClassVar[dict] = {
         "python": "tree_sitter_python",
         "javascript": "tree_sitter_javascript",
         "typescript": "tree_sitter_typescript",
@@ -692,7 +695,7 @@ class MultiLanguageAnalyzer:
         nodes = []
 
         try:
-            with open(file_path, "rb") as f:
+            with file_path.open("rb") as f:
                 source = f.read()
 
             parser = self.parsers[language]
@@ -837,7 +840,7 @@ class CodeTreeAnalyzer:
     """
 
     # Define code file extensions at class level for directory filtering
-    CODE_EXTENSIONS = {
+    CODE_EXTENSIONS: ClassVar[set] = {
         ".py",
         ".js",
         ".jsx",
@@ -888,7 +891,7 @@ class CodeTreeAnalyzer:
     }
 
     # File extensions to language mapping
-    LANGUAGE_MAP = {
+    LANGUAGE_MAP: ClassVar[dict] = {
         ".py": "python",
         ".js": "javascript",
         ".jsx": "javascript",
@@ -1099,7 +1102,7 @@ class CodeTreeAnalyzer:
     def _get_file_hash(self, file_path: Path) -> str:
         """Get hash of file contents for caching."""
         hasher = hashlib.md5()
-        with open(file_path, "rb") as f:
+        with file_path.open("rb") as f:
             hasher.update(f.read())
         return hasher.hexdigest()
 
@@ -1166,7 +1169,7 @@ class CodeTreeAnalyzer:
         cache_file = self.cache_dir / "code_tree_cache.json"
         if cache_file.exists():
             try:
-                with open(cache_file) as f:
+                with cache_file.open() as f:
                     cache_data = json.load(f)
                     # Reconstruct CodeNode objects
                     for key, nodes_data in cache_data.items():
@@ -1203,7 +1206,7 @@ class CodeTreeAnalyzer:
                     for n in nodes
                 ]
 
-            with open(cache_file, "w") as f:
+            with cache_file.open("w") as f:
                 json.dump(cache_data, f, indent=2)
 
             self.logger.info(f"Saved cache with {len(self.cache)} entries")
@@ -1726,7 +1729,7 @@ class CodeTreeAnalyzer:
             },
         }
 
-    def _is_internal_node(self, node: CodeNode) -> bool:  # noqa: PLR0911
+    def _is_internal_node(self, node: CodeNode) -> bool:
         """Check if node is an internal function that should be filtered."""
         # Don't filter classes - always show them
         if node.node_type == "class":
